<?php

namespace Drupal\wn_social_share\Form;

use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;

/**
 * Provides the wn_social_share module configuration form.
 * 提供wn_social_share模块配置表单。
 *
 * @internal
 */
class WnSocialShareConfigForm extends ConfigFormBase {

  public function getFormId() {
    return 'wn_social_share_config';
  }

  protected function getEditableConfigNames() {
    return ['wn_social_share.config'];
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    $config = $this->config('wn_social_share.config');
    $selected = $config->get('social_platforms') != NULL ? $config->get('social_platforms') : [
      'wechat',
      'qq',
      'qzone',
      'weibo',
    ];
    // Third party social platforms to be used.
    // 要使用的第三方社交平台。
    $form['social_platforms'] = [
      '#type' => 'checkboxes',
      '#title' => t('Social platforms for content sharing'),
      '#options' => [
        'wechat' => t('WeChat'),
        'qq' => t('QQ'),
        'qzone' => t('Qzone'),
        'weibo' => t('Weibo'),
      ],
      '#default_value' => $selected,
    ];
    // Setting social platform display order
    // 设置社交平台显示顺序。
    $form['wechat_index'] = [
      '#type' => 'number',
      '#title' => t('WeChat Display Sequence'),
      '#min' => 1,
      '#states' => [
        'visible' => [
          ':input[name="social_platforms[wechat]"][value="wechat"]' => ['checked' => TRUE],
        ],
      ],
      '#default_value' => $config->get('wechat_index') != NULL ? $config->get('wechat_index') : 1,
    ];
    $form['qq_index'] = [
      '#type' => 'number',
      '#title' => t('QQ Display Sequence'),
      '#min' => 1,
      '#states' => [
        'visible' => [
          ':input[name="social_platforms[qq]"][value="qq"]' => ['checked' => TRUE],
        ],
      ],
      '#default_value' => $config->get('qq_index') != NULL ? $config->get('qq_index') : 2,
    ];
    $form['qzone_index'] = [
      '#type' => 'number',
      '#title' => t('Qzone Display Sequence'),
      '#min' => 1,
      '#states' => [
        'visible' => [
          ':input[name="social_platforms[qzone]"][value="qzone"]' => ['checked' => TRUE],
        ],
      ],
      '#default_value' => $config->get('qzone_index') != NULL ? $config->get('qzone_index') : 3,
    ];
    $form['weibo_index'] = [
      '#type' => 'number',
      '#title' => t('Weibo Display Sequence'),
      '#min' => 1,
      '#states' => [
        'visible' => [
          ':input[name="social_platforms[weibo]"][value="weibo"]' => ['checked' => TRUE],
        ],
      ],
      '#default_value' => $config->get('weibo_index') != NULL ? $config->get('weibo_index') : 4,
    ];
    return parent::buildForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function validateForm(array &$form, FormStateInterface $form_state) {}

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    parent::submitForm($form, $form_state);
    $this->config('wn_social_share.config')
      ->set('social_platforms', $form_state->getValue('social_platforms'))
      ->set('wechat_index', $form_state->getValue('wechat_index'))
      ->set('qq_index', $form_state->getValue('qq_index'))
      ->set('qzone_index', $form_state->getValue('qzone_index'))
      ->set('weibo_index', $form_state->getValue('weibo_index'))
      ->save();
  }

}
