<?php

namespace Drupal\wn_social_share\Plugin\views\area;

use Drupal\Core\Config\ConfigFactoryInterface;
use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\Url;
use Drupal\views\Plugin\views\area\AreaPluginBase;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Social share area handler.
 *
 * @ingroup views_area_handlers
 *
 * @ViewsArea("wn_social_share_area")
 */
class WnSocialShareArea extends AreaPluginBase {

  /**
   * Configuration object.
   *
   * @var \Drupal\Core\Config\Config
   */
  protected $config;

  /**
   * Constructs a social share are.
   *
   * @param array $configuration
   *   A configuration array containing information about the plugin instance.
   * @param string $plugin_id
   *   The plugin ID for the plugin instance.
   * @param mixed $plugin_definition
   *   The plugin implementation definition.
   */
  public function __construct(array $configuration, $plugin_id, $plugin_definition, ConfigFactoryInterface $config_factory) {
    parent::__construct($configuration, $plugin_id, $plugin_definition);
    $this->config = $config_factory->get('wn_social_share.config');
  }

  public static function create(ContainerInterface $container, array $configuration, $plugin_id, $plugin_definition) {
    return new static(
      $configuration,
      $plugin_id,
      $plugin_definition,
      $container->get('config.factory')
    );
  }

  /**
   * {@inheritdoc}
   */
  protected function defineOptions() {
    $options = parent::defineOptions();
    $options['class_name'] = [
      'default' => 'wn-social-share',
    ];
    $options['url_type'] = [
      'default' => 'page',
    ];
    return $options;
  }

  /**
   * {@inheritdoc}
   */
  public function buildOptionsForm(&$form, FormStateInterface $form_state) {
    parent::buildOptionsForm($form, $form_state);
    $form['url_type'] = [
      '#type' => 'radios',
      '#title' => $this->t('Sharing Content'),
      '#description' => $this->t('Do you want to share the page where the block is located or website?'),
      '#default_value' => $this->options['url_type'] != NULL ? $this->options['url_type'] : 'page',
      '#options' => [
        'page' => $this->t('Page'),
        'site' => $this->t('Site'),
      ],
    ];
  }

  /**
   * @inheritDoc
   */
  public function render($empty = FALSE) {
    $platforms = "";
    $selected_social_platforms = $this->config->get('social_platforms');
    if (!empty($selected_social_platforms)) {
      $tmp_platforms = [];
      foreach ($selected_social_platforms as $selected_social_platform) {
        // Get platform sequence value from config.
        // 从配置取出每个社交平台的顺序值。
        $tmp_index = $this->config->get("{$selected_social_platform}_index") != NULL ? $this->config->get("{$selected_social_platform}_index") : 1;
        $tmp_platforms[] = [
          'name' => $selected_social_platform,
          'index' => $tmp_index,
        ];
      }
      // Sort array according to index value.
      // 数组按字段index重新排序
      array_multisort(array_column($tmp_platforms, 'index'), SORT_ASC, $tmp_platforms);
      // Retrieve an array with a single column named 'name'.
      // 取出name单一列的数组。
      $arr_platforms = array_column($tmp_platforms, 'name');
      $platforms = join(',', $arr_platforms);
    }
    $data = [
      'platforms' => $platforms,
    ];
    $build = [
      '#theme' => 'wn_social_share',
      '#data' => $data,
    ];
    $build['#attached']['library'][] = 'wn_social_share/share';
    $url_type = $this->options['url_type'] != NULL ? $this->options['url_type'] : 'page';
    $build['#attached']['drupalSettings']['url_type'] = $url_type;
    $build['#attached']['drupalSettings']['base_url'] = Url::fromRoute('<front>', [], ['absolute' => TRUE])
      ->toString();
    return $build;
  }

}
