<?php

namespace Drupal\wn_social_share\Template;

use Drupal\Core\Config\ConfigFactoryInterface;
use Drupal\Core\Url;
use Symfony\Component\DependencyInjection\ContainerInterface;
use Twig\Extension\AbstractExtension;
use Twig\TwigFunction;

/**
 * Defines and registers Drupal Twig extensions for rendering social share.
 * 定义并注册Drupal Twig扩展，用于呈现社交分享。
 *
 * @package Drupal\wn_social_share\Template
 */
class TwigSocialShareExtension extends AbstractExtension {

  /**
   * Configuration object.
   *
   * @var \Drupal\Core\Config\Config
   */
  protected $config;

  /**
   * @param \Drupal\Core\Config\ConfigFactoryInterface $config_factory
   *   The config factory service.
   */
  public function __construct(ConfigFactoryInterface $config_factory) {
    $this->config = $config_factory->get('wn_social_share.config');
  }

  /**
   * @see container
   */
  public static function create(ContainerInterface $container) {
    return new static(
      $container->get('config.factory')
    );
  }

  /**
   * {@inheritdoc}
   */
  public function getName() {
    return 'wn_social_share';
  }

  /**
   * {@inheritdoc}
   */
  public function getFunctions() {
    return [
      new TwigFunction('render_wn_social_share', [
        $this,
        'renderWnSocialShare',
      ]),
    ];
  }

  public function renderWnSocialShare(string $url_type = NULL) {
    $platforms = "";
    $selected_social_platforms = $this->config->get('social_platforms');
    if (!empty($selected_social_platforms)) {
      $tmp_platforms = [];
      foreach ($selected_social_platforms as $selected_social_platform) {
        // Get platform sequence value from config.
        // 从配置取出每个社交平台的顺序值。
        $tmp_index = $this->config->get("{$selected_social_platform}_index") != NULL ? $this->config->get("{$selected_social_platform}_index") : 1;
        $tmp_platforms[] = [
          'name' => $selected_social_platform,
          'index' => $tmp_index,
        ];
      }
      // Sort array according to index value.
      // 数组按字段index重新排序
      array_multisort(array_column($tmp_platforms, 'index'), SORT_ASC, $tmp_platforms);
      // Retrieve an array with a single column named 'name'.
      // 取出name单一列的数组。
      $arr_platforms = array_column($tmp_platforms, 'name');
      $platforms = join(',', $arr_platforms);
    }
    $url_type = $url_type != NULL ? $url_type : 'page';
    $data = [
      'platforms' => $platforms,
      'url_type' => $url_type,
    ];
    $build = [
      '#theme' => 'wn_social_share',
      '#data' => $data,
      '#cache' => [
        'max-age' => 0,
      ],
    ];
    $build['#attached']['library'][] = 'wn_social_share/share';
    $build['#attached']['drupalSettings']['base_url'] = Url::fromRoute('<front>', [], ['absolute' => TRUE])
      ->toString();
    return $build;
  }

}
